#!/usr/bin/env python
from .hesap_makinasi import HesapMakinasi

print("===========NAME===========")
print(__name__)
print("==========================")


def main():
    hm = HesapMakinasi()
    hm.islemlere_basla()


# eğer hazırladığımız paket aynı zamanda kend ibaşına çalışan bir uygulama ise kullanılır. 
# doğrudan çalıştırıldığında uygulamanın ayağa kalması için gerekli kodlar buradan başlatılır
if __name__ == "__main__":
    main()


#!/usr/bin/env python

class HesapMakinasi:

    def __init__(self):
        pass

    def secenek_sun(self) -> int:
        secenek = input("""---------------------------------------------------------
        \n   yapmak istediginiz islemi seciniz:
        \n - Toplama, 1
        \n - Çıkartma, 2
        \n - Çarpma, 3
        \n - Bölme, 4
        \n   Seçiniz:""")

        return int(secenek)


    def topla(self,sayi1:int, sayi2:int):
        return sayi1 + sayi2

    def cikart(self,sayi1:int, sayi2:int):
        return sayi1 - sayi2

    def carp(self,sayi1:int, sayi2:int):
        return sayi1 * sayi2

    def bol(self,sayi1:int, sayi2:int):
        return sayi1 / sayi2

    def islemlere_basla(self):
        while True:
            secenek = self.secenek_sun()
            sayi1 = int(input("sayı1 i giriniz: "))
            sayi2 = int(input("sayı1 i giriniz: "))

            if secenek == 1:
                print(self.topla(sayi1,sayi2))
            elif secenek == 2:
                print(self.cikart(sayi1,sayi2))
            elif secenek == 3:
                print(self.carp(sayi1,sayi2))
            elif secenek == 4:
                print(self.bol(sayi1,sayi2))
            else:
                print("yanlış seçenek")

            devammi = input("devam etmek için e, çıkmak için h: ")
            if devammi =="h":
                break







import pathlib
from setuptools import setup,setuptools

# The directory containing this file
HERE = pathlib.Path(__file__).parent

print(HERE)

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="oguzun-hesap-makinasi",
    version="2.0.0",
    description="muratin hesap makinasi",
    long_description=README,    # check işlemnde ozellikle hata almak için açıklama satırına çevrildi.
    long_description_content_type="text/markdown",
    url="https://github.com/muratcabuk/muratin-hesap-makinasi",
    author="murat cabuk",
    author_email="mcabuk@gmail.com",
    license="MIT",
    classifiers=[
            'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
            'Programming Language :: Python :: 3.4',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python :: 3.7",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src",exclude=("tests",)),
    include_package_data=True,
    install_requires=["requests >= 2.0.0", "click >= 8.0.0"],
    python_requires=">=3.0",
    options={"bdist_wheel": {"universal": "1"}},
    entry_points={
        "console_scripts": [
            "muratin_hesap_makinasi=muratin_hesap_makinasi.__main__:main", 
            # kurulum yapıldıktan sonra doğrudan uygulama gibi çağrılacaksa eşittirin solunda ne yazıyorsa o kelime konsole daçağrılır
        ]
    },
)